==> sumo_1.4.0+dfsg1.orig.tar.xz: sumo-1_4_0/docs/web/docs/Tutorials/OSMActivityGen/eichstaett.osm.md <==
---
title: Tutorials/OSMActivityGen/eichstaett.osm
permalink: /Tutorials/OSMActivityGen/eichstaett.osm/
---

[{{SUMO}}/tests/complex/tutorial/osm_activitygen/eichstaett.osm]({{Source}}tests/complex/tutorial/osm_activitygen/eichstaett.osm)

Map of the German city Eichstätt in the [OpenStreetMap
format](../../OpenStreetMap_file.md). After the map had been exported
from OpenStreetMap, a detail was cut out, unnecessary objects were
deleted and the map has been improved for traffic simulation and for the
conversion with netconvert. The steps are described in [Tutorials/Import
from OpenStreetMap](../../Tutorials/Import_from_OpenStreetMap.md). As
a final step, the XML identifiers were renumbered to positive numbers.
This way, JOSM thinks there are no changes necessary for upload.

You can use this file if you need a road network of a town with about
13,000 inhabitants. All roads were verified to have the right highway
type, speed limit and one-way attribute. All traffic lights of cars (not
all pedestrian lights) were also verified. You can find a corresponding
SUMO network file at
[Tutorials/OSMActivityGen/eichstaett.net.xml](../../Tutorials/OSMActivityGen/eichstaett.net.xml.md).

<table>
<tbody>
<tr class="odd">
<td><p>Author</p></td>
<td><p><a href="http://sourceforge.net/users/w-bamberger">W. Bamberger</a></p></td>
</tr>
<tr class="even">
<td><p>Date</p></td>
<td><p>2011-02-17</p></td>
</tr>
<tr class="odd">
<td><p>Source</p></td>
<td><p>
Map data © <a href="http://www.openstreetmap.org/">OpenStreetMap contributors</a>, <a href="http://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a></p></td>
</tr>
<tr class="even">
<td><p>History</p></td>
<td><p>This file is located in the SUMO repository. See the log there.</p></td>
</tr>
<tr class="odd">
<td><p>License</p></td>
<td><p style="border:1px solid #909090; padding:1px 4px 3px 4px"><img src="../../images/CC-BY-SA-small.png">
This work is licensed under a <a href="http://creativecommons.org/licenses/by-sa/3.0/">Creative Commons Attribution-ShareAlike 3.0 Unported License</a>. The authors are listed in the history.</p>
</td>
</tr>
</tbody>
</table>

==> sumo_1.12.0+dfsg1.orig.tar.xz: sumo-1_12_0/docs/web/docs/Tutorials/OSMActivityGen/eichstaett.osm.md <==
---
title: eichstaett.osm
---

[{{SUMO}}/tests/complex/tutorial/osm_activitygen/eichstaett.osm]({{Source}}tests/complex/tutorial/osm_activitygen/eichstaett.osm)

Map of the German city Eichstätt in the [OpenStreetMap
format](../../OpenStreetMap_file.md). After the map had been exported
from OpenStreetMap, a detail was cut out, unnecessary objects were
deleted and the map has been improved for traffic simulation and for the
conversion with netconvert. The steps are described in [Tutorials/Import
from OpenStreetMap](../../Tutorials/Import_from_OpenStreetMap.md). As
a final step, the XML identifiers were renumbered to positive numbers.
This way, JOSM thinks there are no changes necessary for upload.

You can use this file if you need a road network of a town with about
13,000 inhabitants. All roads were verified to have the right highway
type, speed limit and one-way attribute. All traffic lights of cars (not
all pedestrian lights) were also verified. You can find a corresponding
SUMO network file at
[Tutorials/OSMActivityGen/eichstaett.net.xml](../../Tutorials/OSMActivityGen/eichstaett.net.xml.md).

<table>
<tbody>
<tr class="odd">
<td><p>Author</p></td>
<td><p><a href="http://sourceforge.net/users/w-bamberger">W. Bamberger</a></p></td>
</tr>
<tr class="even">
<td><p>Date</p></td>
<td><p>2011-02-17</p></td>
</tr>
<tr class="odd">
<td><p>Source</p></td>
<td><p>
Map data © <a href="http://www.openstreetmap.org/">OpenStreetMap contributors</a>, <a href="http://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a></p></td>
</tr>
<tr class="even">
<td><p>History</p></td>
<td><p>This file is located in the SUMO repository. See the log there.</p></td>
</tr>
<tr class="odd">
<td><p>License</p></td>
<td><p style="border:1px solid #909090; padding:1px 4px 3px 4px"><img src="../../images/CC-BY-SA-small.png">
This work is licensed under a <a href="http://creativecommons.org/licenses/by-sa/3.0/">Creative Commons Attribution-ShareAlike 3.0 Unported License</a>. The authors are listed in the history.</p>
</td>
</tr>
</tbody>
</table>
